def get_bda(ua: str) -> str:...
async def async_get_bda(ua: str) -> str:...
def get_attestation(number: str, path: str) -> str:...
async def async_get_attestation(number: str, path: str) -> str:...
def get_time() -> int:...
